@@ -252,109 +252,220 @@ def total_mes(base,nombre):
         base['agui_admin_dic'] = bcas[bcas.columns[[x.endswith('_dic') for x in bcas.columns]].tolist()].sum(axis=1)
         base['agui_admin_anual'] = bcas[bcas.columns[[x.endswith('_anual') for x in bcas.columns]].tolist()].sum(axis=1)
 
-def padron_web():
+def padron_web(ruta,almacenar):
 
-    # Definir ruta
+    if almacenar == True:
 
-    ruta='D:'
+        # Definir ruta
 
-    # Creación de carpeta
+        #ruta='D:\eder'
 
-    dir = os.path.join(ruta, 'padron_web')
+        # Creación de carpeta
 
-    if not os.path.exists(dir):
-        os.mkdir(dir)
+        dir = os.path.join(ruta, 'padron_web')
 
-    else:
-        print('Ya existe la carpeta')
-
-    # Extración de enlaces del portal de ESCALE
-
-    url = 'http://escale.minedu.gob.pe/uee/-/document_library_display/GMv7/view/958881'
-
-    http = httplib2.Http()
-
-    response, content = http.request(url)
-
-    links=[]
-
-    for link in BeautifulSoup(content).find_all('a', href=True):
-        links.append(link['href'])
-
-    for link in links:
-        print(link)
-
-    enlace_1 = links [26:30]
-
-    # Establecer enlace con fecha más actual
-
-    l1=enlace_1[0]
-    l2=enlace_1[1]
-    l3=enlace_1[2]
-    l4=enlace_1[3]
-
-    n1=l1[76:81]
-    n2=l2[76:81]
-    n3=l3[76:81]
-    n4=l4[76:81]
-
-    mayor=max(n1,n2,n3,n4)
-
-    enlace_2='http://escale.minedu.gob.pe/uee/-/document_library_display/GMv7/view/958881/'+mayor+';jsessionid=28cf9ab9d37f6fed3dfe4cea19d6?_110_INSTANCE_GMv7_redirect=http%3A%2F%2Fescale.minedu.gob.pe%2Fuee%2F-%2Fdocument_library_display%2FGMv7%2Fview%2F958881%3Bjsessionid%3D28cf9ab9d37f6fed3dfe4cea19d6'
-
-    # Extraer zip del enlace con fecha más actual
-
-    url = enlace_2
-
-    http = httplib2.Http()
-
-    response, content = http.request(url)
-
-    links=[]
-
-    for link in BeautifulSoup(content).find_all('a', href=True):
-        links.append(link['href'])
-
-    for link in links:
-        print(link)
-
-    enlace_3 = links [32:33]
-
-    # Enlace zip con fecha más actual
-
-    e1=enlace_3[0]
-    e2=e1[62:70]
-
-    file = '\padron_web\Padron_web_'+e2+'.zip'
-
-    # Extracción del padrón web en formato dbf
-
-    path = os.path.join(ruta, file)
-
-    if not os.path.exists(path):
-        wget.download(enlace_3[0], 'D:\padron_web')
-        path2=os.path.join(ruta, '\padron_web\Padron_web.dbf')
-
-        if not os.path.exists(path2):
-            fantasy_zip = zipfile.ZipFile('D:\padron_web\Padron_web_'+e2+'.zip')
-            fantasy_zip.extract('Padron_web.dbf', 'D:\padron_web')
-            path3 = 'D:/padron_web/'
-            os.rename(path3+'Padron_web.dbf', path3+'Padron_web_'+e2+'.dbf')
+        if not os.path.exists(dir):
+            os.mkdir(dir)
 
         else:
-            print('Ya existe el Padron_web.dbf')
+            print('Ya existe la carpeta')
 
-    else:
-        print('Ya existe el Padron_web_'+e2+'.zip')
+        # Extración de enlaces del portal de ESCALE
 
-    # Importar Padrón web con fecha más actual a Python
+        url = 'http://escale.minedu.gob.pe/uee/-/document_library_display/GMv7/view/958881'
 
-    # Generar DBF
+        http = httplib2.Http()
 
-    b_dbf=DBF('D:\padron_web\Padron_web_'+e2+'.dbf')
+        response, content = http.request(url)
 
-    # Generar dataframe
+        links=[]
 
-    padweb = pd.DataFrame(iter(b_dbf))
+        for link in BeautifulSoup(content).find_all('a', href=True):
+            links.append(link['href'])
 
-    return padweb
+        for link in links:
+            print(link)
+
+        enlace_1 = links [26:30]
+
+        # Establecer enlace con fecha más actual
+
+        l1=enlace_1[0]
+        l2=enlace_1[1]
+        l3=enlace_1[2]
+        l4=enlace_1[3]
+
+        n1=l1[76:81]
+        n2=l2[76:81]
+        n3=l3[76:81]
+        n4=l4[76:81]
+
+        mayor=max(n1,n2,n3,n4)
+
+        enlace_2='http://escale.minedu.gob.pe/uee/-/document_library_display/GMv7/view/958881/'+mayor+';jsessionid=28cf9ab9d37f6fed3dfe4cea19d6?_110_INSTANCE_GMv7_redirect=http%3A%2F%2Fescale.minedu.gob.pe%2Fuee%2F-%2Fdocument_library_display%2FGMv7%2Fview%2F958881%3Bjsessionid%3D28cf9ab9d37f6fed3dfe4cea19d6'
+
+        # Extraer zip del enlace con fecha más actual
+
+        url = enlace_2
+
+        http = httplib2.Http()
+
+        response, content = http.request(url)
+
+        links=[]
+
+        for link in BeautifulSoup(content).find_all('a', href=True):
+            links.append(link['href'])
+
+        for link in links:
+            print(link)
+
+        enlace_3 = links [32:33]
+
+        # Enlace zip con fecha más actual
+
+        e1=enlace_3[0]
+        e2=e1[62:70]
+
+        file = 'padron_web\Padron_web_'+e2+'.zip'
+
+        # Extracción del padrón web en formato dbf
+
+        path = os.path.join(ruta, file)
+
+        if not os.path.exists(path):
+            wget.download(enlace_3[0], ruta+'\padron_web')
+            path2=os.path.join(ruta, '\padron_web\Padron_web.dbf')
+
+            if not os.path.exists(path2):
+                fantasy_zip = zipfile.ZipFile(ruta+'\padron_web\Padron_web_'+e2+'.zip')
+                fantasy_zip.extract('Padron_web.dbf', ruta+'\padron_web')
+                path3 = ruta+'/padron_web/'
+                os.rename(path3+'Padron_web.dbf', path3+'Padron_web_'+e2+'.dbf')
+
+            else:
+                print('Ya existe el Padron_web.dbf')
+
+        else:
+            print('Ya existe el Padron_web_'+e2+'.zip')
+
+        # Importar Padrón web con fecha más actual a Python
+
+        # Generar DBF
+
+        b_dbf=DBF(ruta+'\padron_web\Padron_web_'+e2+'.dbf')
+
+        # Generar dataframe
+
+        padweb = pd.DataFrame(iter(b_dbf))
+
+        return padweb
+
+    elif almacenar == False:
+
+        # Creación de carpeta
+
+        dir = os.path.join(ruta, 'padron_web')
+
+        if not os.path.exists(dir):
+            os.mkdir(dir)
+
+        else:
+            print('Ya existe la carpeta')
+
+        # Eliminar todos los padrones
+
+        dir = ruta+'\padron_web'
+        for f in os.listdir(dir):
+            os.remove(os.path.join(dir, f))
+
+        # Extración de enlaces del portal de ESCALE
+
+        url = 'http://escale.minedu.gob.pe/uee/-/document_library_display/GMv7/view/958881'
+
+        http = httplib2.Http()
+
+        response, content = http.request(url)
+
+        links=[]
+
+        for link in BeautifulSoup(content).find_all('a', href=True):
+            links.append(link['href'])
+
+        for link in links:
+            print(link)
+
+        enlace_1 = links [26:30]
+
+        # Establecer enlace con fecha más actual
+
+        l1=enlace_1[0]
+        l2=enlace_1[1]
+        l3=enlace_1[2]
+        l4=enlace_1[3]
+
+        n1=l1[76:81]
+        n2=l2[76:81]
+        n3=l3[76:81]
+        n4=l4[76:81]
+
+        mayor=max(n1,n2,n3,n4)
+
+        enlace_2='http://escale.minedu.gob.pe/uee/-/document_library_display/GMv7/view/958881/'+mayor+';jsessionid=28cf9ab9d37f6fed3dfe4cea19d6?_110_INSTANCE_GMv7_redirect=http%3A%2F%2Fescale.minedu.gob.pe%2Fuee%2F-%2Fdocument_library_display%2FGMv7%2Fview%2F958881%3Bjsessionid%3D28cf9ab9d37f6fed3dfe4cea19d6'
+
+        # Extraer zip del enlace con fecha más actual
+
+        url = enlace_2
+
+        http = httplib2.Http()
+
+        response, content = http.request(url)
+
+        links=[]
+
+        for link in BeautifulSoup(content).find_all('a', href=True):
+            links.append(link['href'])
+
+        for link in links:
+            print(link)
+
+        enlace_3 = links [32:33]
+
+        # Enlace zip con fecha más actual
+
+        e1=enlace_3[0]
+        e2=e1[62:70]
+
+        file = 'padron_web\Padron_web_'+e2+'.zip'
+
+        # Extracción del padrón web en formato dbf
+
+        path = os.path.join(ruta, file)
+
+        if not os.path.exists(path):
+            wget.download(enlace_3[0], ruta+'\padron_web')
+            path2=os.path.join(ruta, '\padron_web\Padron_web.dbf')
+
+            if not os.path.exists(path2):
+                fantasy_zip = zipfile.ZipFile(ruta+'\padron_web\Padron_web_'+e2+'.zip')
+                fantasy_zip.extract('Padron_web.dbf', ruta+'\padron_web')
+                path3 = ruta+'/padron_web/'
+                os.rename(path3+'Padron_web.dbf', path3+'Padron_web_'+e2+'.dbf')
+
+            else:
+                print('Ya existe el Padron_web.dbf')
+
+        else:
+            print('Ya existe el Padron_web_'+e2+'.zip')
+
+        # Importar Padrón web con fecha más actual a Python
+
+        # Generar DBF
+
+        b_dbf=DBF(ruta+'\padron_web\Padron_web_'+e2+'.dbf')
+
+        # Generar dataframe
+
+        padweb = pd.DataFrame(iter(b_dbf))
+
+        return padweb
